from _wavg import *

if __name__ == '__main__':
    
    import argparse
    import logging
    import sys

    logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
    logger = logging.getLogger('fasterio')

    parser = argparse.ArgumentParser(
        description="Performs weighted averaging of input imagery")
    parser.add_argument(
        'input', 
        metavar='INPUT', 
        nargs='+',
        help="List of input file names")
    parser.add_argument(
        'output', 
        metavar='OUTPUT',
        help="Output file name")
    parser.add_argument(
        '--origin', 
        metavar='Q', 
        type=float, 
        default=20.0, 
        help="Origin of the weighting function. Default: 20.0")
    parser.add_argument(
        '--exponent', 
        metavar='K', 
        type=float, 
        default=1.0, 
        help="Exponent of the weighting function. Default: 1.0")
    args = parser.parse_args()

    filenames = args.input[:~1]
    output_dir = args.input[-1]
    q = args.origin
    k = args.exponent

    print(q, k)

    avg(filenames, output_dir, q, k)




"""Functions for working with features in a raster dataset."""

import rasterio
from rasterio._features import _shapes, _sieve


def shapes(image, mask=None, connectivity=4, transform=None):
    """Yields a (shape, image_value) pair for each feature in the image.
    
    The shapes are GeoJSON-like dicts and the image values are ints.
    
    Features are found using a connected-component labeling algorithm.

    The image must be of unsigned 8-bit integer (rasterio.byte or
    numpy.uint8) data type. If a mask is provided, pixels for which the
    mask is `True` will be excluded from feature generation.
    """
    if image.dtype.type != rasterio.ubyte:
        raise ValueError("Image must be dtype uint8/ubyte")

    if mask is not None and mask.dtype.type != rasterio.bool_:
        raise ValueError("Mask must be dtype rasterio.bool_")

    with rasterio.drivers():
        for s, v in _shapes(image, mask, transform):
            yield s, v


def sieve(image, size, connectivity=4, output=None):
    """Returns a copy of the image, but with smaller features removed.

    Features smaller than the specified size have their pixel value
    replaced by that of the largest neighboring features.
    
    The image must be of unsigned 8-bit integer (rasterio.byte or
    numpy.uint8) data type.
    """
    if image.dtype.type != rasterio.ubyte:
        raise ValueError("Image must be dtype uint8/ubyte")

    if output is not None and output.dtype.type != rasterio.ubyte:
        raise ValueError("Output must be dtype uint8/ubyte")

    with rasterio.drivers():
        return _sieve(image, size, connectivity)





import code
import collections
import logging
import sys

import numpy

import rasterio


logging.basicConfig(stream=sys.stderr, level=logging.INFO)
logger = logging.getLogger('rasterio')

Stats = collections.namedtuple('Stats', ['min', 'max', 'mean'])

def main(srcfile):
    
    with rasterio.drivers(), rasterio.open(srcfile) as src:
        
        def show(source):
            """Show a raster using matplotlib.

            The raster may be either an ndarray or a (dataset, bidx)
            tuple.
            """
            import matplotlib.pyplot as plt
            if isinstance(source, tuple):
                arr = source[0].read_band(source[1])
            else:
                arr = source
            plt.imshow(arr)
            plt.gray()
            plt.show()

        def stats(source):
            """Return a tuple with raster min, max, and mean.
            """
            if isinstance(source, tuple):
                arr = source[0].read_band(source[1])
            else:
                arr = source
            return Stats(numpy.min(arr), numpy.max(arr), numpy.mean(arr))

        code.interact(
            'Rasterio %s Interactive Inspector (Python %s)\n'
            'Type "src.meta", "src.read_band(1)", or "help(src)" '
            'for more information.' %  (
                rasterio.__version__, 
                '.'.join(map(str, sys.version_info[:3]))),
            local=dict(
                    locals(), np=numpy, rio=rasterio))
    
    return 1

if __name__ == '__main__':
    
    import argparse

    parser = argparse.ArgumentParser(
        prog="python -m rasterio.tool",
        description="Open a dataset and drop into an interactive interpreter")
    parser.add_argument(
        'src', 
        metavar='FILE', 
        help="Input dataset file name")
    args = parser.parse_args()
    
    main(args.src)

